metertools.MeterManager
=======================

.. abjad-lineage:: abjad.tools.metertools.MeterManager.MeterManager

.. autoclass:: abjad.tools.metertools.MeterManager.MeterManager

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.metertools.MeterManager.MeterManager.is_acceptable_logical_tie
      ~abjad.tools.metertools.MeterManager.MeterManager.is_boundary_crossing_logical_tie
      ~abjad.tools.metertools.MeterManager.MeterManager.iterate_rewrite_inputs
      ~abjad.tools.metertools.MeterManager.MeterManager.__eq__
      ~abjad.tools.metertools.MeterManager.MeterManager.__format__
      ~abjad.tools.metertools.MeterManager.MeterManager.__hash__
      ~abjad.tools.metertools.MeterManager.MeterManager.__ne__
      ~abjad.tools.metertools.MeterManager.MeterManager.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Static methods
--------------

.. automethod:: abjad.tools.metertools.MeterManager.MeterManager.is_acceptable_logical_tie
   :noindex:

.. automethod:: abjad.tools.metertools.MeterManager.MeterManager.is_boundary_crossing_logical_tie
   :noindex:

.. automethod:: abjad.tools.metertools.MeterManager.MeterManager.iterate_rewrite_inputs
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.metertools.MeterManager.MeterManager.__eq__
   :noindex:

.. automethod:: abjad.tools.metertools.MeterManager.MeterManager.__format__
   :noindex:

.. automethod:: abjad.tools.metertools.MeterManager.MeterManager.__hash__
   :noindex:

.. automethod:: abjad.tools.metertools.MeterManager.MeterManager.__ne__
   :noindex:

.. automethod:: abjad.tools.metertools.MeterManager.MeterManager.__repr__
   :noindex:
